@@ -2878,6 +2878,30 @@ static void smoothing1( int njob, int nadd, int lenfull, char **seq, Blocktoreal
 //	for( i=0; i<lenfull+1; i++ ) fprintf( stderr, "i=%d, nnewres=%d, start=%d, end=%d\n", i, realign[i].nnewres, realign[i].start, realign[i].end );
 }
 	
+static double ratioambiguouscolumn_simple( char **s, int n, int l )
+{
+	int i, j;
+	int nunambiguous;
+	int nambiguous;
+	if( dorp == 'd' )
+		nunambiguous = 4;
+	else
+		nunambiguous = 6;
+
+	nambiguous = 0;
+	for( i=0; i<l; i++ )
+	{
+		for( j=0; j<n; j++ )
+			if( amino_grp[(int)s[j][i]] < nunambiguous )
+				break;
+		if( j == n )
+			nambiguous += 1;
+	}
+
+	reporterr( "nambiguous = %d / %d, ratio=%f\n", nambiguous, l, (double)nambiguous / l );
+	return( (double)nambiguous / l );
+}
+
 int main( int argc, char *argv[] )
 {
 	static int  *nlen;	
@@ -3270,6 +3294,17 @@ int main( int argc, char *argv[] )
 	commongappick( norg, seq );
 	lenfull = strlen( seq[0] );
 
+	if( ratioambiguouscolumn_simple( seq, norg, lenfull ) > 0.03 )
+	{
+		fprintf( stderr, "################################################################################\n" );
+		fprintf( stderr, "# \n" );
+		fprintf( stderr, "# The reference MSA has >3%% ambiguous columns.\n" );
+		fprintf( stderr, "# Please prepare a better reference.\n" );
+		fprintf( stderr, "# \n" );
+		fprintf( stderr, "################################################################################\n" );
+		exit( 1 );
+	}
+
 	if( keeplength && mapout )
 	{
 		addbk = (char **)calloc( nadd+1, sizeof( char * ) );
@@ -3701,6 +3736,9 @@ int main( int argc, char *argv[] )
 
 
 
+	if( commonIP ) FreeIntMtx( commonIP );
+	commonIP = NULL;
+	A__align( NULL, 0, 0, NULL, NULL, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0, -1, -1, NULL, NULL, NULL, 0.0, 0.0 );
 	FreeIntMtx( newgaplist_o );
 	FreeIntVec( newgaplist_compact );
 	FreeIntVec( posmap );
