@@ -481,6 +481,8 @@ int main( int argc, char *argv[] )
 
 	nkozo = 0;
 
+
+
 	if( njob < 2 ) 
 	{
 		seq = AllocateCharMtx( 2, nlenmax*1+1 );
@@ -501,6 +503,25 @@ int main( int argc, char *argv[] )
 	}
 
 
+	if( nlenmax < 1 )
+	{
+		seq = AllocateCharMtx( njob, nlenmax*1+1 );
+    	name = AllocateCharMtx( njob, B+1 );
+//	    nlen = AllocateIntVec( 2 ); 
+		readData_pointer( infp, name, nlen, seq );
+		fclose( infp );
+		initFiles();
+		for( i=0; i<njob; i++ ) strcpy( seq[i], "" );
+		writeData_pointer( prep_g, njob, name, nlen, seq );
+		reporterr( "Warning: No sequence found.\n", njob ); 
+		FreeCharMtx( seq );
+		FreeCharMtx( name );
+//		free( nlen );
+		closeFiles();
+		exit( 0 );
+	}
+
+
 	if( subalignment )
 	{
 		readsubalignmentstable( njob, NULL, NULL, &nsubalignments, &maxmem );
