@@ -2475,7 +2475,8 @@ static void pairalign( char **name, int *nlen, char **seq, char **aseq, char **d
 		if( ngui == 0 )
 		{
 			if( alg == 'Y' || alg == 'r' )
-				distancemtx = AllocateDoubleMtx( njob, nadd );
+//				distancemtx = AllocateDoubleMtx( njob, nadd );
+				distancemtx = AllocateDoubleMtx( njob-nadd, nadd ); // 2020/Oct/23
 			else
 				distancemtx = AllocateDoubleHalfMtx( njob );
 //				distancemtx = AllocateDoubleMtx( njob, njob );
@@ -3051,7 +3052,13 @@ static void pairalign( char **name, int *nlen, char **seq, char **aseq, char **d
 	}
 	free( distseq1 );
 	free( distseq2 );
-	if( store_dist && ngui == 0 ) FreeDoubleHalfMtx( distancemtx, njob );
+	if( store_dist && ngui == 0 ) 
+	{
+		if( alg == 'Y' || alg == 'r' )
+			FreeDoubleMtx( distancemtx ); // 2020/Oct/23
+		else
+			FreeDoubleHalfMtx( distancemtx, njob );
+	}
 
 	free( targetmap );
 	free( targetmapr );
