@@ -675,7 +675,7 @@ static double Atracking( double *lasthorizontalw, double *lastverticalw,
 	return( 0.0 );
 }
 
-double partA__align( char **seq1, char **seq2, double *eff1, double *eff2, int icyc, int jcyc, int alloclen, LocalHom ***localhom, double *impmatch, int start1, int end1, int start2, int end2, int *gapmap1, int *gapmap2, char *sgap1, char *sgap2, char *egap1, char *egap2, int *chudanpt, int chudanref, int *chudanres )
+double partA__align( char **seq1, char **seq2, double *eff1, double *eff2, int icyc, int jcyc, int alloclen, int constraint, double *impmatch, int start1, int end1, int start2, int end2, int *gapmap1, int *gapmap2, char *sgap1, char *sgap2, char *egap1, char *egap2, int *chudanpt, int chudanref, int *chudanres )
 /* score no keisan no sai motokaraaru gap no atukai ni mondai ga aru */
 {
 //	int k;
@@ -1042,12 +1042,12 @@ double partA__align( char **seq1, char **seq2, double *eff1, double *eff2, int i
 
 
 	match_calc( initverticalw, cpmx2, cpmx1, 0, lgth1, doublework, intwork, 1 );
-	if( localhom )
+	if( constraint )
 		part_imp_match_out_vead_tate_gapmap( initverticalw, gapmap2[0]+start2, lgth1, start1, gapmap1 );
 
 
 	match_calc( currentw, cpmx1, cpmx2, 0, lgth2, doublework, intwork, 1 );
-	if( localhom )
+	if( constraint )
 		part_imp_match_out_vead_gapmap( currentw, gapmap1[0]+start1, lgth2, start2, gapmap2 );
 #if 0 // -> tbfast.c
 	if( localhom )
@@ -1061,11 +1061,17 @@ double partA__align( char **seq1, char **seq2, double *eff1, double *eff2, int i
 		{
 //			initverticalw[i] += ( ogcp1[0] + fgcp1[i-1] ) ;
 			initverticalw[i] += ( ogcp1[0] * headgapfreq2 + fgcp1[i-1] * gapfreq2[0] ) ;
+#if USE_PENALTY_EX
+			tsuika hitsuyou
+#endif
 		}
 		for( j=1; j<lgth2+1; j++ )
 		{
 //			currentw[j] += ( ogcp2[0] + fgcp2[j-1] ) ;
 			currentw[j] += ( ogcp2[0] * headgapfreq1 + fgcp2[j-1] * gapfreq1[0] ) ;
+#if USE_PENALTY_EX
+			tsuika hitsuyou
+#endif
 		}
 	}
 #if OUTGAP0TRY
@@ -1139,7 +1145,7 @@ for( j=0; j<lgth2; j++ )
 }
 fprintf( stderr, "\n" );
 #endif
-		if( localhom )
+		if( constraint )
 		{
 //			fprintf( stderr, "Calling imp_match_calc (o) lgth = %d, i = %d\n", lgth1, i );
 //			imp_match_out_vead( currentw, i, lgth2 );
@@ -1208,7 +1214,8 @@ fprintf( stderr, "\n" );
 				*ijppt = -( j - mpi );
 			}
 //			g = *prept + *ogcp2pt * gapfreq1[i-1];
-			if( (g = *prept + *ogcp2pt * gf1vapre) >= mi )
+//			if( (g = *prept + *ogcp2pt * gf1vapre) >= mi )
+			if( (g = *prept + *ogcp2pt * gf1vapre) > mi ) // 2018/Apr
 			{
 				mi = g;
 				mpi = j-1;
@@ -1224,7 +1231,8 @@ fprintf( stderr, "\n" );
 				*ijppt = +( i - *mpjpt );
 			}
 //			g = *prept + ogcp1va * gapfreq2[j-1];
-			if( (g = *prept + ogcp1va * *gf2ptpre) >= *mjpt )
+//			if( (g = *prept + ogcp1va * *gf2ptpre) >= *mjpt ) 
+			if( (g = *prept + ogcp1va * *gf2ptpre) > *mjpt ) // 2018/Apr
 			{
 				*mjpt = g;
 				*mpjpt = i-1;
@@ -1330,7 +1338,7 @@ fprintf( stderr, "\n" );
 	for( i=0; i<icyc; i++ ) strcpy( mseq1[i], seq1[i] );
 	for( j=0; j<jcyc; j++ ) strcpy( mseq2[j], seq2[j] );
 	*/
-	if( localhom )
+	if( constraint )
 	{
 		Atracking_localhom( impmatch, currentw, lastverticalw, seq1, seq2, mseq1, mseq2, ijp, icyc, jcyc, start1, end1, start2, end2, gapmap1, gapmap2, warpis, warpjs, warpbase );
 	}
@@ -1363,7 +1371,7 @@ fprintf( stderr, "\n" );
 	return( wm );
 }
 
-double partA__align_variousdist( int **which, double ***matrices, double **n_dynamicmtx, char **seq1, char **seq2, double *eff1, double *eff2, double **eff1s, double **eff2s, int icyc, int jcyc, int alloclen, LocalHom ***localhom, double *impmatch, int start1, int end1, int start2, int end2, int *gapmap1, int *gapmap2, char *sgap1, char *sgap2, char *egap1, char *egap2, int *chudanpt, int chudanref, int *chudanres )
+double partA__align_variousdist( int **which, double ***matrices, double **n_dynamicmtx, char **seq1, char **seq2, double *eff1, double *eff2, double **eff1s, double **eff2s, int icyc, int jcyc, int alloclen, int constraint, double *impmatch, int start1, int end1, int start2, int end2, int *gapmap1, int *gapmap2, char *sgap1, char *sgap2, char *egap1, char *egap2, int *chudanpt, int chudanref, int *chudanres )
 /* score no keisan no sai motokaraaru gap no atukai ni mondai ga aru */
 {
 //	int k;
@@ -1494,7 +1502,6 @@ double partA__align_variousdist( int **which, double ***matrices, double **n_dyn
 				{
 					masklist1[c] = realloc( masklist1[c], sizeof( int ) * (nmask[c]+1) );
 					masklist2[c] = realloc( masklist2[c], sizeof( int ) * (nmask[c]+1) );
-
 					masklist1[c][nmask[c]] = i;
 					masklist2[c][nmask[c]] = j;
 					nmask[c]++;
@@ -1761,7 +1768,7 @@ double partA__align_variousdist( int **which, double ***matrices, double **n_dyn
 		if( nmask[c] ) match_calc_del( which, matrices, initverticalw, jcyc, seq2, eff2, icyc, seq1, eff1, 0, lgth1, c, nmask[c], masklist2[c], masklist1[c] );
 	}
 
-	if( localhom )
+	if( constraint )
 		part_imp_match_out_vead_tate_gapmap( initverticalw, gapmap2[0]+start2, lgth1, start1, gapmap1 );
 
 
@@ -1772,9 +1779,9 @@ double partA__align_variousdist( int **which, double ***matrices, double **n_dyn
 		match_calc_add( matrices[c], currentw, cpmx1s[c], cpmx2s[c], 0, lgth2, doublework[c], intwork[c], 1 );
 		if( nmask[c] ) match_calc_del( which, matrices, currentw, icyc, seq1, eff1, jcyc, seq2, eff2, 0, lgth2, c, nmask[c], masklist1[c], masklist2[c] );
 	}
-	if( localhom )
+	if( constraint )
 		part_imp_match_out_vead_gapmap( currentw, gapmap1[0]+start1, lgth2, start2, gapmap2 );
-#if 0 // -> tbfast.c
+#if 0 // -> tbfast.c, localhom ga hitsuyou
 	if( localhom )
 		imp_match_calc( currentw, icyc, jcyc, lgth1, lgth2, seq1, seq2, eff1, eff2, localhom, 1, 0 );
 
@@ -1786,11 +1793,17 @@ double partA__align_variousdist( int **which, double ***matrices, double **n_dyn
 		{
 //			initverticalw[i] += ( ogcp1[0] + fgcp1[i-1] ) ;
 			initverticalw[i] += ( ogcp1[0] * headgapfreq2 + fgcp1[i-1] * gapfreq2[0] ) ;
+#if USE_PENALTY_EX
+			tsuika hitsuyou 
+#endif
 		}
 		for( j=1; j<lgth2+1; j++ )
 		{
 //			currentw[j] += ( ogcp2[0] + fgcp2[j-1] ) ;
 			currentw[j] += ( ogcp2[0] * headgapfreq1 + fgcp2[j-1] * gapfreq1[0] ) ;
+#if USE_PENALTY_EX
+			tsuika hitsuyou 
+#endif
 		}
 	}
 #if OUTGAP0TRY
@@ -1873,7 +1886,7 @@ for( j=0; j<lgth2; j++ )
 }
 fprintf( stderr, "\n" );
 #endif
-		if( localhom )
+		if( constraint )
 		{
 //			fprintf( stderr, "Calling imp_match_calc (o) lgth = %d, i = %d\n", lgth1, i );
 //			imp_match_out_vead( currentw, i, lgth2 );
@@ -1945,7 +1958,8 @@ fprintf( stderr, "\n" );
 				*ijppt = -( j - mpi );
 			}
 //			g = *prept + *ogcp2pt * gapfreq1[i-1];
-			if( (g = *prept + *ogcp2pt * gf1vapre) >= mi )
+//			if( (g = *prept + *ogcp2pt * gf1vapre) >= mi )
+			if( (g = *prept + *ogcp2pt * gf1vapre) > mi ) // 2018/Apr
 			{
 				mi = g;
 				mpi = j-1;
@@ -1961,7 +1975,8 @@ fprintf( stderr, "\n" );
 				*ijppt = +( i - *mpjpt );
 			}
 //			g = *prept + ogcp1va * gapfreq2[j-1];
-			if( (g = *prept + ogcp1va * *gf2ptpre) >= *mjpt )
+//			if( (g = *prept + ogcp1va * *gf2ptpre) >= *mjpt )
+			if( (g = *prept + ogcp1va * *gf2ptpre) > *mjpt ) // 2018/Apr
 			{
 				*mjpt = g;
 				*mpjpt = i-1;
@@ -2067,7 +2082,7 @@ fprintf( stderr, "\n" );
 	for( i=0; i<icyc; i++ ) strcpy( mseq1[i], seq1[i] );
 	for( j=0; j<jcyc; j++ ) strcpy( mseq2[j], seq2[j] );
 	*/
-	if( localhom )
+	if( constraint )
 	{
 		Atracking_localhom( impmatch, currentw, lastverticalw, seq1, seq2, mseq1, mseq2, ijp, icyc, jcyc, start1, end1, start2, end2, gapmap1, gapmap2, warpis, warpjs, warpbase );
 	}
